GroupDisplay

Struct GroupDisplay 

pub struct GroupDisplay<K, W, S: EngineSpec> { /* private fields */ }
A displayer that simultaneously manages and shows line-based output for several event buffers.

K is the key type for each element in the group. Its fmt::Display impl is called to obtain the prefix, and Eq + Ord is used for keys.

Implementations

Source

impl<K: Eq + Ord, W: Write, S: EngineSpec> GroupDisplay<K, W, S>

pub fn new<Str>( log: &Logger, keys_and_prefixes: impl IntoIterator<Item = (K, Str)>, writer: W, ) -> Self
where Str: Into<String>,

Creates a new GroupDisplay with the provided report keys and prefixes.

The function passed in is expected to create a writer.

pub fn new_with_display( log: &Logger, keys: impl IntoIterator<Item = K>, writer: W, ) -> Self
where K: Display,

Creates a new GroupDisplay with the provided report keys, using the Display impl to obtain the respective prefixes.

pub fn set_styles(&mut self, styles: LineDisplayStyles)

Sets the styles for all future lines.

pub fn set_start_time(&mut self, start_time: DateTime<Utc>)

Sets the start time for all future lines.

If the start time is set, the progress display will be relative to that time. Otherwise, only the offset from the start of the job will be displayed.

pub fn set_progress_interval(&mut self, interval: Duration)

Sets the amount of time before new progress events are shown.

pub fn contains_key<Q>(&self, key: &Q) -> bool
where K: Borrow<Q>, Q: Ord,

Returns true if this GroupDisplay is producing reports corresponding to the given key.

pub fn add_event_report<Q>( &mut self, key: &Q, event_report: EventReport<S>, ) -> Result<(), UnknownReportKey>
where K: Borrow<Q>, Q: Ord,

Adds an event report to the display, keyed by the index, and updates internal state.

Returns Ok(()) if the report was accepted because the key was known to this GroupDisplay, and an error if it was not.

pub fn write_stats(&mut self, header: &str) -> Result<()>

Writes a “Status” or “Summary” line to the writer with statistics.

pub fn write_events(&mut self) -> Result<()>

Writes all pending events to the writer.

pub fn stats(&self) -> &GroupDisplayStats

Returns the current statistics for this GroupDisplay.