GroupDisplayStats

Struct GroupDisplayStats 

pub struct GroupDisplayStats {
    pub total: usize,
    pub not_started: usize,
    pub running: usize,
    pub completed: usize,
    pub failed: usize,
    pub aborted: usize,
    pub overwritten: usize,
}

Fields

total: usize

The total number of reports.

not_started: usize

The number of reports that have not yet started.

running: usize

The number of reports that are currently running.

completed: usize

The number of reports that indicate successful completion.

failed: usize

The number of reports that indicate failure.

aborted: usize

The number of reports that indicate being aborted.

overwritten: usize

The number of reports where we didn’t receive a final state and it got overwritten by another report.

Overwritten reports are considered failures since we don’t know what happened.

Implementations

Source

impl GroupDisplayStats

pub fn terminal_count(&self) -> usize

Returns the number of terminal reports.

pub fn is_terminal(&self) -> bool

Returns true if all reports have reached a terminal state.

pub fn has_failures(&self) -> bool

Returns true if there are any failures.