pub struct GroupDisplayStats {
pub total: usize,
pub not_started: usize,
pub running: usize,
pub completed: usize,
pub failed: usize,
pub aborted: usize,
pub overwritten: usize,
}Fields
total: usizeThe total number of reports.
not_started: usizeThe number of reports that have not yet started.
running: usizeThe number of reports that are currently running.
completed: usizeThe number of reports that indicate successful completion.
failed: usizeThe number of reports that indicate failure.
aborted: usizeThe number of reports that indicate being aborted.
overwritten: usizeThe number of reports where we didn’t receive a final state and it got overwritten by another report.
Overwritten reports are considered failures since we don’t know what happened.
Implementations
Sourceimpl GroupDisplayStats
impl GroupDisplayStats
Sourcepub fn terminal_count(&self) -> usize
pub fn terminal_count(&self) -> usize
Returns the number of terminal reports.
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Returns true if all reports have reached a terminal state.
Sourcepub fn has_failures(&self) -> bool
pub fn has_failures(&self) -> bool
Returns true if there are any failures.