LineDisplay

Struct LineDisplay 

pub struct LineDisplay<W> { /* private fields */ }
A line-oriented display.

This display produces output to the provided writer.

Implementations

Source

impl<W: Write> LineDisplay<W>

pub fn new(writer: W) -> Self

Creates a new LineDisplay.

pub fn set_prefix(&mut self, prefix: impl Into<String>)

Sets the prefix for all future lines.

pub fn set_styles(&mut self, styles: LineDisplayStyles)

Sets the styles for all future lines.

pub fn set_start_time(&mut self, start_time: DateTime<Utc>)

Sets the start time for all future lines.

If the start time is set, then the progress display will be relative to that time. Otherwise, only the offset from the start of the job will be displayed.

pub fn set_progress_interval(&mut self, interval: Duration)

Sets the amount of time before the next progress event is shown.

pub fn write_event_buffer<S: EngineSpec>( &mut self, buffer: &EventBuffer<S>, ) -> Result<()>

Writes an event buffer to the writer, incrementally.

This is a stateful method that will only display events that have not been displayed before.

pub fn write_terminal_info( &mut self, info: &ExecutionTerminalInfo, ) -> Result<()>

Writes terminal information to the writer.

pub fn write_generic(&mut self, message: &str) -> Result<()>

Writes a generic line to the writer, with prefix attached if provided.